@@ -1,5 +1,5 @@
 package GitLab::API::v3::Constants;
-$GitLab::API::v3::Constants::VERSION = '0.05';
+$GitLab::API::v3::Constants::VERSION = '0.06';
 =head1 NAME
 
 GitLab::API::v3::Constants - GitLab API v3 constants.
@@ -23,44 +23,44 @@ our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 =head1 CONSTANTS
 
-=head2 $GITLAB_PRIVATE_VISIBILITY_LEVEL
+=head2 $GITLAB_VISIBILITY_LEVEL_PRIVATE
 
 C<0>
 
 =cut
 
-const our $GITLAB_PRIVATE_VISIBILITY_LEVEL  => 0;
-push @EXPORT_OK, '$GITLAB_PRIVATE_VISIBILITY_LEVEL';
+const our $GITLAB_VISIBILITY_LEVEL_PRIVATE  => 0;
+push @EXPORT_OK, '$GITLAB_VISIBILITY_LEVEL_PRIVATE';
 
-=head2 $GITLAB_INTERNAL_VISIBILITY_LEVEL
+=head2 $GITLAB_VISIBILITY_LEVEL_INTERNAL
 
 C<10>
 
 =cut
 
-const our $GITLAB_INTERNAL_VISIBILITY_LEVEL => 10;
-push @EXPORT_OK, '$GITLAB_INTERNAL_VISIBILITY_LEVEL';
+const our $GITLAB_VISIBILITY_LEVEL_INTERNAL => 10;
+push @EXPORT_OK, '$GITLAB_VISIBILITY_LEVEL_INTERNAL';
 
-=head2 $GITLAB_PUBLIC_VISIBILITY_LEVEL
+=head2 $GITLAB_VISIBILITY_LEVEL_PUBLIC
 
 C<20>
 
 =cut
 
-const our $GITLAB_PUBLIC_VISIBILITY_LEVEL   => 20;
-push @EXPORT_OK, '$GITLAB_PUBLIC_VISIBILITY_LEVEL';
+const our $GITLAB_VISIBILITY_LEVEL_PUBLIC   => 20;
+push @EXPORT_OK, '$GITLAB_VISIBILITY_LEVEL_PUBLIC';
 
 =head2 @GITLAB_VISIBILITY_LEVELS
 
-An array containing the values for L</$GITLAB_PRIVATE_VISIBILITY_LEVEL>,
-L</$GITLAB_INTERNAL_VISIBILITY_LEVEL> and L</$GITLAB_PUBLIC_VISIBILITY_LEVEL>.
+An array containing the values for L</$GITLAB_VISIBILITY_LEVEL_PRIVATE>,
+L</$GITLAB_VISIBILITY_LEVEL_INTERNAL> and L</$GITLAB_VISIBILITY_LEVEL_PUBLIC>.
 
 =cut
 
 const our @GITLAB_VISIBILITY_LEVELS => (
-    $GITLAB_PRIVATE_VISIBILITY_LEVEL,
-    $GITLAB_INTERNAL_VISIBILITY_LEVEL,
-    $GITLAB_PUBLIC_VISIBILITY_LEVEL,
+    $GITLAB_VISIBILITY_LEVEL_PRIVATE,
+    $GITLAB_VISIBILITY_LEVEL_INTERNAL,
+    $GITLAB_VISIBILITY_LEVEL_PUBLIC,
 );
 push @EXPORT_OK, '@GITLAB_VISIBILITY_LEVELS';
 
@@ -131,7 +131,7 @@ __END__
 
 =head1 AUTHOR
 
-Aran Clary Deltac <bluefeet@gmail.com>
+Aran Clary Deltac <bluefeetE<64>gmail.com>
 
 =head1 LICENSE
 
